==> mod_uploader-2.2.6.tgz: mod_uploader-2.2.6/src/ApacheRFC2822Parser.cpp <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: ApacheRFC2822Parser.cpp 2162 2006-12-03 14:36:10Z svn $
 *****************************************************************************/

#include "ApacheRFC2822Parser.h"

#include "Environment.h"

#include "SourceInfo.h"
#define TEMPLATE_INSTANTIATION
#include "BasicFileWriter.cpp"
#include "Base64FileWriter.cpp"
#include "MultipartMessageParser.cpp"
#include "RFC2822Parser.cpp"

SOURCE_INFO_ADD("$Id: ApacheRFC2822Parser.cpp 2162 2006-12-03 14:36:10Z svn $");

template class Base64FileWriter<BasicFileWriter>;
template class MultipartMessageParser<ApacheRequestReader, Base64FileWriter<BasicFileWriter> >;
template class RFC2822Parser<ApacheRequestReader>;

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:

==> mod_uploader-2.6.2.tgz: mod_uploader-2.6.2/src/ApacheRFC2822Parser.cpp <==
/******************************************************************************
 * Copyright (C) 2006 Tetsuya Kimata <kimata@acapulco.dyndns.org>
 *
 * All rights reserved.
 *
 * This software is provided 'as-is', without any express or implied
 * warranty.  In no event will the authors be held liable for any
 * damages arising from the use of this software.
 *
 * Permission is granted to anyone to use this software for any
 * purpose, including commercial applications, and to alter it and
 * redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must
 *    not claim that you wrote the original software. If you use this
 *    software in a product, an acknowledgment in the product
 *    documentation would be appreciated but is not required.
 *
 * 2. Altered source versions must be plainly marked as such, and must
 *    not be misrepresented as being the original software.
 *
 * 3. This notice may not be removed or altered from any source
 *    distribution.
 *
 * $Id: ApacheRFC2822Parser.cpp 2685 2007-11-17 22:35:04Z svn $
 *****************************************************************************/

#include "ApacheRFC2822Parser.h"

#include "Environment.h"

#include "SourceInfo.h"
#define TEMPLATE_INSTANTIATION
#include "Base64FileWriter.cpp"
#include "MultipartMessageParser.cpp"
#include "RFC2822Parser.cpp"

SOURCE_INFO_ADD("$Id: ApacheRFC2822Parser.cpp 2685 2007-11-17 22:35:04Z svn $");

template class Base64FileWriter<>;
template class MultipartMessageParser<ApacheRequestReader, Base64FileWriter<> >;
template class RFC2822Parser<ApacheRequestReader>;

// Local Variables:
// mode: c++
// coding: utf-8-dos
// End:
